==> PureAI-0.0.9-cp311-none-manylinux_2_17_x86_64.whl: pureai/libtorch_config.py <==
import os
import ctypes
import sys
import shutil
import zipfile
import requests
import platform


def set_custom_libstdc():
    """
    Define a variável de ambiente LD_LIBRARY_PATH para priorizar a versão do libstdc++ personalizada.
    """
    libstdc_path = os.path.join(os.path.dirname(__file__))
    if os.path.exists(os.path.join(libstdc_path, "libstdc++.so.6")):
        os.environ["LD_LIBRARY_PATH"] = libstdc_path + \
            ":" + os.environ.get("LD_LIBRARY_PATH", "")
        print(f"✅ Usando libstdc++ personalizado de {libstdc_path}")
    else:
        print("❌ libstdc++.so.6 não encontrado no diretório 'libs/'")
        sys.exit(1)


def load_libtorch():
    LIBTORCH_DIR = "./libtorch"
    LIBTORCH_CPU_ZIP = "libtorch-cxx11-abi-shared-with-deps-2.5.1+cpu.zip"
    LIBTORCH_CPU_URL = "https://download.pytorch.org/libtorch/cpu/libtorch-cxx11-abi-shared-with-deps-2.5.1%2Bcpu.zip"
    LIBTORCH_CPU_PATH = os.path.join(LIBTORCH_DIR, "cpu")
    LIBTORCH_LIB_PATH = os.path.join(LIBTORCH_CPU_PATH, "lib")
    LIBTORCH_BIN_PATH = os.path.join(LIBTORCH_CPU_PATH, "bin")

    if not os.path.exists(LIBTORCH_CPU_PATH):
        set_custom_libstdc()
        if os.path.exists(LIBTORCH_CPU_ZIP):
            os.remove(LIBTORCH_CPU_ZIP)

        response = requests.get(LIBTORCH_CPU_URL, stream=True)
        with open(LIBTORCH_CPU_ZIP, "wb") as file:
            for chunk in response.iter_content(chunk_size=8192):
                file.write(chunk)

        os.makedirs(LIBTORCH_DIR, exist_ok=True)

        if platform.system() == "Windows":
            with zipfile.ZipFile(LIBTORCH_CPU_ZIP, "r") as zip_ref:
                zip_ref.extractall(LIBTORCH_DIR)
        else:
            os.system(f"unzip {LIBTORCH_CPU_ZIP} -d {LIBTORCH_DIR}")

        shutil.move(os.path.join(LIBTORCH_DIR, "libtorch"), LIBTORCH_CPU_PATH)

    if platform.system() == "Windows":
        os.environ["PATH"] = LIBTORCH_BIN_PATH + \
            ";" + os.environ.get("PATH", "")
    else:
        os.environ["LD_LIBRARY_PATH"] = LIBTORCH_LIB_PATH + \
            ":" + os.environ.get("LD_LIBRARY_PATH", "")

    try:
        if platform.system() == "Windows":
            for dll_file in os.listdir(LIBTORCH_BIN_PATH):
                if dll_file.endswith(".dll"):
                    ctypes.CDLL(os.path.join(LIBTORCH_BIN_PATH, dll_file))
        else:
            for so_file in os.listdir(LIBTORCH_LIB_PATH):
                if so_file.endswith(".so"):
                    ctypes.CDLL(os.path.join(LIBTORCH_LIB_PATH, so_file))
    except OSError as e:
        print(f"❌ Error to load libtorch")
        sys.exit(1)

==> PureAI-0.0.10-cp311-none-manylinux_2_35_x86_64.whl: pureai/libtorch_config.py <==
import os
import ctypes
import sys
import shutil
import zipfile
import requests
import platform


def load_libtorch():
    LIBTORCH_DIR = "./libtorch"
    LIBTORCH_CPU_ZIP = "libtorch-cxx11-abi-shared-with-deps-2.5.1+cpu.zip"
    LIBTORCH_CPU_URL = "https://download.pytorch.org/libtorch/cpu/libtorch-cxx11-abi-shared-with-deps-2.5.1%2Bcpu.zip"
    LIBTORCH_CPU_PATH = os.path.join(LIBTORCH_DIR, "cpu")
    LIBTORCH_LIB_PATH = os.path.join(LIBTORCH_CPU_PATH, "lib")
    LIBTORCH_BIN_PATH = os.path.join(LIBTORCH_CPU_PATH, "bin")

    lib_path = os.path.dirname(__file__)
    os.environ["LD_LIBRARY_PATH"] = lib_path + \
        ":" + os.environ.get("LD_LIBRARY_PATH", "")

    if sys.platform == "linux":
        import ctypes
        ctypes.cdll.LoadLibrary(os.path.join(lib_path, "libstdc++.so.6"))

    if not os.path.exists(LIBTORCH_CPU_PATH):
        if os.path.exists(LIBTORCH_CPU_ZIP):
            os.remove(LIBTORCH_CPU_ZIP)

        response = requests.get(LIBTORCH_CPU_URL, stream=True)
        with open(LIBTORCH_CPU_ZIP, "wb") as file:
            for chunk in response.iter_content(chunk_size=8192):
                file.write(chunk)

        os.makedirs(LIBTORCH_DIR, exist_ok=True)

        if platform.system() == "Windows":
            with zipfile.ZipFile(LIBTORCH_CPU_ZIP, "r") as zip_ref:
                zip_ref.extractall(LIBTORCH_DIR)
        else:
            os.system(f"unzip {LIBTORCH_CPU_ZIP} -d {LIBTORCH_DIR}")

        shutil.move(os.path.join(LIBTORCH_DIR, "libtorch"), LIBTORCH_CPU_PATH)

    if platform.system() == "Windows":
        os.environ["PATH"] = LIBTORCH_BIN_PATH + \
            ";" + os.environ.get("PATH", "")
    else:
        os.environ["LD_LIBRARY_PATH"] = LIBTORCH_LIB_PATH + \
            ":" + os.environ.get("LD_LIBRARY_PATH", "")

    try:
        if platform.system() == "Windows":
            for dll_file in os.listdir(LIBTORCH_BIN_PATH):
                if dll_file.endswith(".dll"):
                    ctypes.CDLL(os.path.join(LIBTORCH_BIN_PATH, dll_file))
        else:
            for so_file in os.listdir(LIBTORCH_LIB_PATH):
                if so_file.endswith(".so"):
                    ctypes.CDLL(os.path.join(LIBTORCH_LIB_PATH, so_file))
    except OSError as e:
        print(f"❌ Error to load libtorch")
        sys.exit(1)
